Enum sp_core::ExecutionContext [−][src]
pub enum ExecutionContext {
Importing,
Syncing,
BlockConstruction,
OffchainCall(Option<(Box<dyn Externalities>, Capabilities)>),
}Expand description
Context for executing a call into the runtime.
Variants
Context used for general block import (including locally authored blocks).
Context used for importing blocks as part of an initial sync of the blockchain.
We distinguish between major sync and import so that validators who are running their initial sync (or catching up after some time offline) can use the faster native runtime (since we can reasonably assume the network as a whole has already come to a broad conensus on the block and it probably hasn’t been crafted specifically to attack this node), but when importing blocks at the head of the chain in normal operation they can use the safer Wasm version.
Context used for block construction.
OffchainCall(Option<(Box<dyn Externalities>, Capabilities)>)Context used for offchain calls.
This allows passing offchain extension and customizing available capabilities.
Tuple Fields of OffchainCall
0: Option<(Box<dyn Externalities>, Capabilities)>Implementations
Returns the capabilities of particular context.