Struct sp_core::H160 [−][src]
Fixed-size uninterpreted hash type with 20 bytes (160 bits) size.
Tuple Fields
0: [u8; 20]Implementations
Returns a new fixed hash where all bits are set to the given byte.
Extracts a mutable byte slice containing the entire fixed hash.
Extracts a reference to the byte array containing the entire fixed hash.
Extracts a reference to the byte array containing the entire fixed hash.
Returns the inner bytes array.
Returns a mutable raw pointer to the value.
Utilities using the byteorder crate.
Returns the lowest 8 bytes interpreted as big-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
Returns the lowest 8 bytes interpreted as little-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
Returns the lowest 8 bytes interpreted as native-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as big endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as little endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as native endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
Utilities using the rand crate.
Assign self to a cryptographically random value using the
given random number generator.
Create a new hash with cryptographically random content using the given random number generator.