Struct sp_core::traits::ReadRuntimeVersionExt
source · [−]pub struct ReadRuntimeVersionExt(pub Box<dyn ReadRuntimeVersion>);Expand description
An extension that provides functionality to read version information from a given wasm blob.
Tuple Fields
0: Box<dyn ReadRuntimeVersion>Implementations
sourceimpl ReadRuntimeVersionExt
impl ReadRuntimeVersionExt
sourcepub fn new<T: ReadRuntimeVersion + 'static>(inner: T) -> Self
pub fn new<T: ReadRuntimeVersion + 'static>(inner: T) -> Self
Creates a new instance of the extension given a version determinator instance.