Struct sp_core::traits::RuntimeCode
source · [−]pub struct RuntimeCode<'a> {
pub code_fetcher: &'a dyn FetchRuntimeCode,
pub heap_pages: Option<u64>,
pub hash: Vec<u8>,
}Expand description
The Wasm code of a Substrate runtime.
Fields
code_fetcher: &'a dyn FetchRuntimeCodeThe code fetcher that can be used to lazily fetch the code.
heap_pages: Option<u64>The optional heap pages this code should be executed with.
If None are given, the default value of the executor will be used.
hash: Vec<u8>The SCALE encoded hash of code.
The hashing algorithm isn’t that important, as long as all runtime code instances use the same.
Implementations
sourceimpl<'a> RuntimeCode<'a>
impl<'a> RuntimeCode<'a>