Derive

Trait Derive 

pub trait Derive: Sized {
    // Provided method
    fn derive<Iter: Iterator<Item = DeriveJunction>>(
        &self,
        _path: Iter,
    ) -> Option<Self> { ... }
}
Derivable key trait.

Provided Methods

fn derive<Iter: Iterator<Item = DeriveJunction>>( &self, _path: Iter, ) -> Option<Self>

Derive a child key from a series of given junctions.

Will be None for public keys if there are any hard junctions in there.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Derive for Dummy

Source

impl Derive for Public

Source

impl<const N: usize, SubTag> Derive for PublicBytes<N, SubTag>
where Self: CryptoType,