pub trait Wraps: Sized {
type Inner: IsWrappedBy<Self>;
// Provided method
fn as_inner_ref(&self) -> &Self::Inner { ... }
}Expand description
Opposite of IsWrappedBy - denotes a type which is a simple wrapper around another type.
Required Associated Types
Sourcetype Inner: IsWrappedBy<Self>
type Inner: IsWrappedBy<Self>
The inner type it is wrapping.
Provided Methods
Sourcefn as_inner_ref(&self) -> &Self::Inner
fn as_inner_ref(&self) -> &Self::Inner
Get a reference to the inner type that is wrapped.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".