SpawnEssentialNamed

Trait SpawnEssentialNamed 

pub trait SpawnEssentialNamed:
    DynClone
    + Send
    + Sync {
    // Required methods
    fn spawn_essential_blocking(
        &self,
        name: &'static str,
        group: Option<&'static str>,
        future: BoxFuture<'static, ()>,
    );
    fn spawn_essential(
        &self,
        name: &'static str,
        group: Option<&'static str>,
        future: BoxFuture<'static, ()>,
    );
}
Something that can spawn essential tasks (blocking and non-blocking) with an assigned name and optional group.

Essential tasks are special tasks that should take down the node when they end.

Required Methods

fn spawn_essential_blocking( &self, name: &'static str, group: Option<&'static str>, future: BoxFuture<'static, ()>, )

Spawn the given blocking future.

The given group and name is used to identify the future in tracing.

fn spawn_essential( &self, name: &'static str, group: Option<&'static str>, future: BoxFuture<'static, ()>, )

Spawn the given non-blocking future.

The given group and name is used to identify the future in tracing.