SpawnNamed

Trait SpawnNamed 

pub trait SpawnNamed:
    DynClone
    + Send
    + Sync {
    // Required methods
    fn spawn_blocking(
        &self,
        name: &'static str,
        group: Option<&'static str>,
        future: BoxFuture<'static, ()>,
    );
    fn spawn(
        &self,
        name: &'static str,
        group: Option<&'static str>,
        future: BoxFuture<'static, ()>,
    );
}
Something that can spawn tasks (blocking and non-blocking) with an assigned name and optional group.

Required Methods

fn spawn_blocking( &self, name: &'static str, group: Option<&'static str>, future: BoxFuture<'static, ()>, )

Spawn the given blocking future.

The given group and name is used to identify the future in tracing.

fn spawn( &self, name: &'static str, group: Option<&'static str>, future: BoxFuture<'static, ()>, )

Spawn the given non-blocking future.

The given group and name is used to identify the future in tracing.